diff dmd/scope.h @ 1141:f99a3b393c03

Reorganize EnclosingHandlers to require less changes to the frontend and allow us to implement the synchronized storage class for functions.
author Christian Kamm <kamm incasoftware de>
date Tue, 24 Mar 2009 21:18:18 +0100
parents 041c1596d217
children e961851fb8be
line wrap: on
line diff
--- a/dmd/scope.h	Tue Mar 24 14:34:16 2009 +0100
+++ b/dmd/scope.h	Tue Mar 24 21:18:18 2009 +0100
@@ -46,8 +46,8 @@
     Dsymbol *parent;		// parent to use
     LabelStatement *slabel;	// enclosing labelled statement
     SwitchStatement *sw;	// enclosing switch statement
-    TryFinallyStatement *tf;	// enclosing try finally statement; set inside its finally block
-    EnclosingHandler *tfOfTry; // enclosing try-finally, volatile or synchronized statement; set inside its try or body block
+    TryFinallyStatement *enclosingFinally;	// enclosing try finally statement; set inside its finally block
+    Statement *enclosingScopeExit; // enclosing statement that wants to do something on scope exit
     TemplateInstance *tinst;	// enclosing template instance
     Statement *sbreak;		// enclosing statement that supports "break"
     Statement *scontinue;	// enclosing statement that supports "continue"